@@ -130,7 +130,8 @@ class Replies:
             ) as fp:
                 filename = fp.name
             with open(filename, "wb") as f:
-                f.write(bytefile.read())
+                with bytefile:
+                    f.write(bytefile.read())
 
         if not viewtype:
             if filename:
@@ -255,14 +256,14 @@ class DeltaBot:
         assert "/" not in scope and "/" not in name
         old_val = self.get(name, scope=scope)
         key = scope + "/" + name
-        self.plugins._pm.hook.deltabot_store_setting(key=key, value=value)
+        self.plugins.hook.deltabot_store_setting(key=key, value=value)
         return old_val
 
     def delete(self, name: str, scope: str = "global") -> None:
         """Delete a bot setting with the given scope."""
         assert "/" not in scope
         key = scope + "/" + name
-        self.plugins._pm.hook.deltabot_store_setting(key=key, value=None)
+        self.plugins.hook.deltabot_store_setting(key=key, value=None)
 
     def get(
         self, name: str, default: str = None, scope: str = "global"
@@ -270,7 +271,7 @@ class DeltaBot:
         """Get a bot setting from the given scope."""
         assert "/" not in scope
         key = scope + "/" + name
-        res = self.plugins._pm.hook.deltabot_get_setting(key=key)
+        res = self.plugins.hook.deltabot_get_setting(key=key)
         return res if res is not None else default
 
     def list_settings(self, scope: str = None) -> list:
@@ -279,7 +280,7 @@ class DeltaBot:
         If scope is not specified, all settings are returned.
         """
         assert scope is None or "/" not in scope
-        l = self.plugins._pm.hook.deltabot_list_settings()
+        l = self.plugins.hook.deltabot_list_settings()
         if scope is not None:
             scope_prefix = scope + "/"
             l = [
@@ -368,7 +369,6 @@ class DeltaBot:
                 # set some useful bot defaults on the account
                 delete_server_after=1,
                 delete_device_after=2592000,
-                save_mime_headers=1,
                 e2ee_enabled=1,
                 sentbox_watch=0,
                 mvbox_move=0,
@@ -453,21 +453,19 @@ class CheckAll:
         for msg_id in self.db.get_msgs():
             try:
                 message = self.bot.account.get_message_by_id(msg_id)
-                message.mark_seen()
-                headers = message.get_mime_headers() or dict()
-                can_encrypt = (
-                    from_dc_charpointer(
+                sender = message.get_sender_contact()
+                if sender != self.bot.self_contact:
+                    message.mark_seen()
+                    encrinfo = from_dc_charpointer(
                         lib.dc_get_contact_encrinfo(
                             self.bot.account._dc_context,
-                            message.get_sender_contact().id,
+                            sender.id,
                         )
                     )
-                    .splitlines()[0]
-                    .lower()
-                    != "no encryption."
-                )
-                is_deltalab = "Chat-Version" in headers and "Subject" not in headers
-                if message.is_encrypted() or can_encrypt or is_deltalab:
+                    can_encrypt = encrinfo.splitlines()[0].lower() != "no encryption."
+                else:
+                    can_encrypt = True
+                if message.is_encrypted() or can_encrypt:
                     replies = Replies(message, logger=logger)
                     logger.info("processing incoming fresh message id=%s", message.id)
                     if message.is_system_message():
@@ -483,7 +481,9 @@ class CheckAll:
                             )
                     replies.send_reply_messages()
                 else:
-                    logger.debug("ignoring classic email id=%s", msg_id)
+                    logger.info(
+                        "ignoring message (id=%s) without autocrypt support", msg_id
+                    )
                 logger.info("processing message id=%s FINISHED", msg_id)
             except Exception as ex:
                 logger.exception("processing message=%s failed: %s", msg_id, ex)
