@@ -2,11 +2,10 @@ import os
 import sys
 from typing import Optional
 
-from deltachat import Account  # type: ignore
-
 from .bot import DeltaBot
 from .parser import MyArgumentParser, get_base_parser
 from .plugins import get_global_plugin_manager
+from .utils import BotAccount
 
 
 def main(argv=None) -> None:
@@ -30,9 +29,9 @@ def make_bot_from_args(args, plugin_manager, account=None) -> Optional[DeltaBot]
     if not os.path.exists(args.basedir):
         os.makedirs(args.basedir)
 
+    logger = plugin_manager.hook.deltabot_get_logger(args=args)
     if account is None:
         db_path = os.path.join(args.basedir, "account.db")
-        account = Account(db_path, "simplebot/{}".format(sys.platform))
+        account = BotAccount(db_path, "simplebot/{}".format(sys.platform), logger)
 
-    logger = plugin_manager.hook.deltabot_get_logger(args=args)
     return DeltaBot(account, logger, plugin_manager=plugin_manager, args=args)
